==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/DataLegendSummaryColumn.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { DataLegendSeriesValueInfo } from "./DataLegendSeriesValueInfo";
import { List$1 } from "./List$1";
import { HashSet$1 } from "./HashSet$1";
import { Number_$type, String_$type, markType } from "./type";
/**
 * @hidden
 */
var DataLegendSummaryColumn = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataLegendSummaryColumn, _super);
    function DataLegendSummaryColumn() {
        var _this = _super.call(this) || this;
        _this.ag = new List$1(Number_$type, 0);
        _this.ae = new List$1(String_$type, 0);
        _this.af = new List$1(String_$type, 0);
        _this.ac = new HashSet$1(String_$type, 0);
        _this.ad = new HashSet$1(String_$type, 0);
        _this.a = 15;
        return _this;
    }
    Object.defineProperty(DataLegendSummaryColumn.prototype, "ab", {
        get: function () {
            return this.ag.toArray();
        },
        enumerable: false,
        configurable: true
    });
    DataLegendSummaryColumn.prototype.aj = function (a) {
        this.ag.add(a);
    };
    DataLegendSummaryColumn.prototype.ah = function (a) {
        if (!this.ac.contains(a)) {
            this.ac.add_1(a);
            this.ae.add(a);
        }
    };
    DataLegendSummaryColumn.prototype.ai = function (a) {
        if (!this.ad.contains(a)) {
            this.ad.add_1(a);
            this.af.add(a);
        }
    };
    Object.defineProperty(DataLegendSummaryColumn.prototype, "z", {
        get: function () {
            return this.ae.toArray();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DataLegendSummaryColumn.prototype, "aa", {
        get: function () {
            return this.af.toArray();
        },
        enumerable: false,
        configurable: true
    });
    DataLegendSummaryColumn.$t = markType(DataLegendSummaryColumn, 'DataLegendSummaryColumn', DataLegendSeriesValueInfo.$);
    return DataLegendSummaryColumn;
}(DataLegendSeriesValueInfo));
export { DataLegendSummaryColumn };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/DataLegendSummaryColumn.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { DataLegendSeriesValueInfo } from "./DataLegendSeriesValueInfo";
import { List$1 } from "./List$1";
import { HashSet$1 } from "./HashSet$1";
import { Number_$type, String_$type, markType } from "./type";
/**
 * @hidden
 */
var DataLegendSummaryColumn = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataLegendSummaryColumn, _super);
    function DataLegendSummaryColumn() {
        var _this = _super.call(this) || this;
        _this.ah = new List$1(Number_$type, 0);
        _this.af = new List$1(String_$type, 0);
        _this.ag = new List$1(String_$type, 0);
        _this.ad = new HashSet$1(String_$type, 0);
        _this.ae = new HashSet$1(String_$type, 0);
        _this.a = 15;
        return _this;
    }
    Object.defineProperty(DataLegendSummaryColumn.prototype, "ac", {
        get: function () {
            return this.ah.toArray();
        },
        enumerable: false,
        configurable: true
    });
    DataLegendSummaryColumn.prototype.ak = function (a) {
        this.ah.add(a);
    };
    DataLegendSummaryColumn.prototype.ai = function (a) {
        if (!this.ad.contains(a)) {
            this.ad.add_1(a);
            this.af.add(a);
        }
    };
    DataLegendSummaryColumn.prototype.aj = function (a) {
        if (!this.ae.contains(a)) {
            this.ae.add_1(a);
            this.ag.add(a);
        }
    };
    Object.defineProperty(DataLegendSummaryColumn.prototype, "aa", {
        get: function () {
            return this.af.toArray();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DataLegendSummaryColumn.prototype, "ab", {
        get: function () {
            return this.ag.toArray();
        },
        enumerable: false,
        configurable: true
    });
    DataLegendSummaryColumn.$t = markType(DataLegendSummaryColumn, 'DataLegendSummaryColumn', DataLegendSeriesValueInfo.$);
    return DataLegendSummaryColumn;
}(DataLegendSeriesValueInfo));
export { DataLegendSummaryColumn };
